from phdictionary.dictionary import get_definition, \
    get_synonym, \
    get_french_english, \
    get_english_french, \
    get_synonyms_from_file, \
    get_french_english_from_file, \
    get_definition_from_file, \
    get_english_french_from_file, \
    get_french_russian, \
    get_russian_french, \
    get_russian_english, \
    get_english_russian
